@@ -26,6 +26,7 @@ extern "C"
 
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qpainter.h>
 #include <qbuttongroup.h>
@@ -34,6 +35,8 @@ extern "C"
 
 // Include files for KDE
 
+#include <kprogress.h>
+#include <kprocess.h>
 #include <ksimpleconfig.h>
 #include <klistbox.h>
 #include <kprinter.h>
@@ -55,10 +58,12 @@ extern "C"
 
 // Local includes
 
+#include "kpaboutdata.h"
+#include "pluginsversion.h"
 #include "utils.h"
 #include "cropframe.h"
 #include "frmprintwizard.h"
-
+#include "frmprintwizard.moc"
 
 namespace KIPIPrintWizardPlugin
 {
@@ -90,21 +95,18 @@ FrmPrintWizard::FrmPrintWizard(QWidget *parent, const char *name )
   // ---------------------------------------------------------------
 
   // About data and help button.
-    
-  KAboutData* about = new KAboutData("kipiplugins",
-                                     I18N_NOOP("Print Wizard"), 
-                                     "0.1.0-cvs",
-                                     I18N_NOOP("A KIPI plugin to print images"),
-                                     KAboutData::License_GPL,
-                                     "(c) 2003-2004, Todd Shoemaker", 
-                                     0,
-                                     "http://extragear.kde.org/apps/kipi");
-    
-  about->addAuthor("Todd Shoemaker", I18N_NOOP("Author"),
-                   "todd@theshoemakers.net");
+
+  m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Print Wizard"),
+                                         NULL,
+                                         KAboutData::License_GPL,
+                                         I18N_NOOP("A KIPI plugin to print images"),
+                                         "(c) 2003-2004, Todd Shoemaker");
+
+  m_about->addAuthor("Todd Shoemaker", I18N_NOOP("Author"),
+                     "todd@theshoemakers.net");
 
   m_helpButton = helpButton();
-  KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
+  KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
   helpMenu->menu()->removeItemAt(0);
   helpMenu->menu()->insertItem(i18n("Print Wizard Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
   m_helpButton->setPopup( helpMenu->menu() );
@@ -151,6 +153,9 @@ FrmPrintWizard::FrmPrintWizard(QWidget *parent, const char *name )
   connect(BtnPreviewPageDown, SIGNAL(clicked(void)),
           this, SLOT(BtnPreviewPageDown_clicked(void)));
   loadSettings();
+
+  m_Proc = new KProcess;
+  *m_Proc << "kjobviewer" << "--all";
 }
 
 FrmPrintWizard::~FrmPrintWizard()
@@ -159,6 +164,8 @@ FrmPrintWizard::~FrmPrintWizard()
     if (m_photos.at(i))
       delete m_photos.at(i);
   m_photos.clear();
+
+  delete m_about;
 }
 
 void FrmPrintWizard::slotHelp()
@@ -541,6 +548,9 @@ void FrmPrintWizard::printPhotos(QPtrList<TPhoto> photos, QPtrList<QRect> layout
   p.end();
 
   this->finishButton()->setEnabled(true);
+  if (m_kjobviewer->isChecked())
+    if ( !m_Proc->start() )
+      kdDebug( 51000 ) << "Error running kjobviewr\n";
   LblPrintProgress->setText(i18n("Complete.  Click Finish to exit the Print Wizard."));
 }
 
@@ -614,7 +624,12 @@ QStringList FrmPrintWizard::printPhotosToFile(QPtrList<TPhoto> photos, QString &
   if (printing)
     LblPrintProgress->setText(i18n("Printing Canceled."));
   else
+  {
+    if (m_kjobviewer->isChecked())
+      if ( !m_Proc->start() )
+        kdDebug( 51000 ) << "Error launching kjobviewr\n";
     LblPrintProgress->setText(i18n("Complete.  Click Finish to exit the Print Wizard."));
+  }
   return files;
 }
 
@@ -653,6 +668,9 @@ void FrmPrintWizard::loadSettings()
   else
     ListPhotoSizes->setCurrentItem(0);
 
+  // kjobviewer
+  m_kjobviewer->setChecked(config.readBoolEntry("KjobViewer", true));
+
   EditCopies->setValue(config.readNumEntry("Copies", EditCopies->value()));
 }
 
@@ -687,6 +705,9 @@ void FrmPrintWizard::saveSettings()
   config.writeEntry("PhotoSize", ListPhotoSizes->currentText());
   config.writeEntry("Copies", EditCopies->value());
 
+  // kjobviewer
+  config.writeEntry("KjobViewer", m_kjobviewer->isChecked());
+
 }
 
 void FrmPrintWizard::GrpOutputSettings_clicked(int id)
@@ -1108,4 +1129,3 @@ void FrmPrintWizard::initPhotoSizes(KPrinter::PageSize pageSize)
 
 }  // NameSpace KIPIPrintWizardPlugin
 
-#include "frmprintwizard.moc"
